@@ -17,13 +17,11 @@ class TestProjectAnalysisPerformer(unittest.TestCase):
         
         self.test_struct1 = ap.AnalysisPerformer(
             "test-demo",
-            prjroot3_filename,
-            output_path=r"C:\Users\tonyz\AppData\Local\Temp\EVASE_DEMO222_1c70afaa-074f-422c-89bb-44bf02a74d89_w9dlbc3k"
+            prjroot3_filename
         )
         self.test_struct2 = ap.AnalysisPerformer(
             "test-demo",
-            prjroot2_filename,
-            output_path=r"C:\Users\tonyz\AppData\Local\Temp\EVASE_DEMO222_1c70afaa-074f-422c-89bb-44bf02a74d89_w9dlbc3k"
+            prjroot2_filename
         )
 
     def test_dependency_graph(self):
@@ -31,6 +29,7 @@ class TestProjectAnalysisPerformer(unittest.TestCase):
         Tests the ability of the analysis performer to construct the proper graph.
         """
 
+        self.test_struct1.strategy = ap.SQLInjectionBehaviourAnalyzer()
         self.test_struct1.perform_analysis()
         results = self.test_struct1.get_results()
 
@@ -47,6 +46,7 @@ class TestProjectAnalysisPerformer(unittest.TestCase):
             all([x in nodes_present for x in all_package_names])
         )
 
+        self.test_struct2.strategy = ap.SQLInjectionBehaviourAnalyzer()
         self.test_struct2.perform_analysis()
         results = self.test_struct2.get_results()
 
